@@ -82,7 +82,35 @@ static bool CheckFFmpegEnv()
     QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
     dir.setPath(path);
     QStringList list = dir.entryList(QStringList() << (QString("libavcodec") + "*"), QDir::NoDotAndDotDot | QDir::Files);
-    if (list.contains("libavcodec.so.58")) {
+    QString libName = nullptr;
+    QRegExp re("libavcodec.so.*"); //Sometimes libavcodec.so may not exist, so find it through regular expression.
+    for (int i = 0; i < list.count(); i++) {
+        if (re.exactMatch(list[i])) {
+            libName = list[i];
+            break;
+        }
+    }
+
+    if (libName != nullptr) {
+        QLibrary libavcodec;  //检查编码器是否存在
+        libavcodec.setFileName(libName);
+        qDebug() << "Whether the libavcodec is loaded successfully: "<< libavcodec.load();
+        typedef AVCodec *(*p_avcodec_find_encoder)(enum AVCodecID id);
+        p_avcodec_find_encoder m_avcodec_find_encoder = nullptr;
+        m_avcodec_find_encoder = reinterpret_cast<p_avcodec_find_encoder>(libavcodec.resolve("avcodec_find_encoder"));
+
+        AVCodec *pCodec = nullptr;
+        if (m_avcodec_find_encoder)
+            pCodec = m_avcodec_find_encoder(AV_CODEC_ID_H264);
+
+        if (pCodec) {
+            qDebug() << "Video encoder exists. AVCodecID:" << AV_CODEC_ID_H264;
+            DataManager::instance()->setEncExists(true);
+        } else {
+            qWarning() << "Can not find output video encoder! AVCodecID:" << AV_CODEC_ID_H264;
+            DataManager::instance()->setEncExists(false);
+        }
+
         return true;
     }
     return false;
