@@ -247,9 +247,9 @@ void MajorImageProcessingThread::run()
 
             // 判断是否使用rgb数据
             bool bUseRgb = false;
-    #ifdef __mips__
+#if defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64) || defined (__mips__)
             bUseRgb = true;
-    #endif
+#endif
             if (get_wayland_status())
                 bUseRgb = true;
 
@@ -461,6 +461,8 @@ void MajorImageProcessingThread::run()
     #ifdef UNITTEST
             break;
     #endif
+            //保证画面流畅的前提下降低刷新率
+            msleep(33);
         }
 
         v4l2core_stop_stream(m_videoDevice);
