@@ -215,7 +215,7 @@ videowidget::videowidget(DWidget *parent)
     setGridType(Grid_None);
 
     if (dc::Settings::get().getOption("outsetting.outformat.vidformat").toInt() ||
-            DataManager::instance()->encodeEnv() != FFmpeg_Env)
+            DataManager::instance()->encodeEnv() != FFmpeg_Env || !DataManager::instance()->encExists())
         m_videoFormat = "webm";
 }
 
@@ -230,8 +230,6 @@ void videowidget::delayInit()
     setFlash(dc::Settings::get().getOption("photosetting.Flashlight.Flashlight").toBool());
     setCapStatus(false);
     m_imgPrcThread->m_bTake = false;
-    connect(m_imgPrcThread, SIGNAL(SendMajorImageProcessing(QImage *, int)),
-            this, SLOT(ReceiveMajorImage(QImage *, int)));
     if (get_wayland_status() == true) {
         connect(m_imgPrcThread, SIGNAL(SendMajorImageProcessing(QImage *, int)),
                 this, SLOT(ReceiveMajorImage(QImage *, int)));
